==> qtjambi-xml-6.2.9-sources.jar: io/qt/xml/QDomDocumentType.java <==
package io.qt.xml;


/**
 * <p>The representation of the DTD in the document tree</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomdocumenttype.html">QDomDocumentType</a></p>
 */
public class QDomDocumentType extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#QDomDocumentType">QDomDocumentType::QDomDocumentType()</a></p>
     */
    public QDomDocumentType(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomDocumentType instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#QDomDocumentType-1">QDomDocumentType::QDomDocumentType(QDomDocumentType)</a></p>
     */
    public QDomDocumentType(io.qt.xml.QDomDocumentType x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomDocumentType instance, io.qt.xml.QDomDocumentType x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#entities">QDomDocumentType::entities()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QDomNamedNodeMap entities(){
        return entities_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QDomNamedNodeMap entities_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#internalSubset">QDomDocumentType::internalSubset()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String internalSubset(){
        return internalSubset_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String internalSubset_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#name">QDomDocumentType::name()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#notations">QDomDocumentType::notations()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QDomNamedNodeMap notations(){
        return notations_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QDomNamedNodeMap notations_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#publicId">QDomDocumentType::publicId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#systemId">QDomDocumentType::systemId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomDocumentType(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomDocumentType clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomDocumentType clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.2.12-sources.jar: io/qt/xml/QDomDocumentType.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>The representation of the DTD in the document tree</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomdocumenttype.html">QDomDocumentType</a></p>
 */
public class QDomDocumentType extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#QDomDocumentType">QDomDocumentType::QDomDocumentType()</a></p>
     */
    public QDomDocumentType(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomDocumentType instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#QDomDocumentType-1">QDomDocumentType::QDomDocumentType(QDomDocumentType)</a></p>
     */
    public QDomDocumentType(io.qt.xml.@NonNull QDomDocumentType x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomDocumentType instance, io.qt.xml.QDomDocumentType x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#entities">QDomDocumentType::entities()const</a></p>
     */
    @QtUninvokable
    public final io.qt.xml.@NonNull QDomNamedNodeMap entities(){
        return entities_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xml.QDomNamedNodeMap entities_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#internalSubset">QDomDocumentType::internalSubset()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String internalSubset(){
        return internalSubset_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String internalSubset_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#name">QDomDocumentType::name()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#notations">QDomDocumentType::notations()const</a></p>
     */
    @QtUninvokable
    public final io.qt.xml.@NonNull QDomNamedNodeMap notations(){
        return notations_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xml.QDomNamedNodeMap notations_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#operator-eq">QDomDocumentType::operator=(QDomDocumentType)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomDocumentType arg__1){
        assign_native_cref_QDomDocumentType(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomDocumentType(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#publicId">QDomDocumentType::publicId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumenttype.html#systemId">QDomDocumentType::systemId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomDocumentType(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomDocumentType clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomDocumentType clone_native(long __this_nativeId);
}
